SMExercise class

Constructors

SMExercise({String? name, int? totalSeconds, int? introSeconds, String? videoInstruction, String? exerciseIntro, List<UIElement>? uiElements, String? detector, bool? repBased, String? exerciseClosure, int? targetReps, int? targetTime, double? scoreFactor})

Properties

detector ↔ String?
getter/setter pair
exerciseClosure ↔ String?
getter/setter pair
exerciseIntro ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
introSeconds ↔ int?
getter/setter pair
name ↔ String?
getter/setter pair
repBased ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scoreFactor ↔ double?
getter/setter pair
targetReps ↔ int?
getter/setter pair
targetTime ↔ int?
getter/setter pair
totalSeconds ↔ int?
getter/setter pair
uiElements ↔ List<UIElement>?
getter/setter pair
videoInstruction ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited