SMWorkout class

Constructors

SMWorkout({String? id, String? name, String? workoutIntro, String? soundTrack, required List<SMExercise> exercises, String? getInFrame, String? bodycalFinished, String? workoutClosure})

Properties

bodycalFinished ↔ String?
getter/setter pair
exercises ↔ List<SMExercise>
getter/setter pair
getInFrame ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
soundTrack ↔ String?
getter/setter pair
workoutClosure ↔ String?
getter/setter pair
workoutIntro ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited